@@ -3,9 +3,10 @@
 *************************************************/
 
 /* Experimental DMARC support.
-   Copyright (c) The Exim Maintainers 2021 - 2022
+   Copyright (c) The Exim Maintainers 2021 - 2023
    Copyright (c) Todd Lyons <tlyons@exim.org> 2012 - 2014
    License: GPL */
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 
 /* Portions Copyright (c) 2012, 2013, The Trusted Domain Project;
    All rights reserved, licensed for use per LICENSE.opendmarc. */
@@ -19,9 +20,9 @@
 
 /* prototypes */
 gstring * dmarc_version_report(gstring *);
-int dmarc_init();
+int dmarc_init(void);
 int dmarc_store_data(header_line *);
-int dmarc_process();
+int dmarc_process(void);
 uschar *dmarc_exim_expand_query(int);
 uschar *dmarc_exim_expand_defaults(int);
 
@@ -57,4 +58,8 @@ uschar *dmarc_exim_expand_defaults(int);
 #define ARES_RESULT_UNKNOWN 11
 #define ARES_RESULT_DISCARD 12
 
+#define	DMARC_ARC_POLICY_RESULT_PASS	0
+#define	DMARC_ARC_POLICY_RESULT_UNUSED	1
+#define	DMARC_ARC_POLICY_RESULT_FAIL	2
+
 #endif /* SUPPORT_DMARC */
